"""OilLevelSpecification"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.list_with_selected_item import (
    promote_to_list_with_selected_item,
)
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private import _0
from mastapy._private._internal import (
    constructor,
    conversion,
    enum_with_selected_value_runtime,
    utility,
)
from mastapy._private._internal.implicit import (
    enum_with_selected_value,
    list_with_selected_item,
)
from mastapy._private.math_utility import _1723
from mastapy._private.system_model.part_model import _2719
from mastapy._private.system_model.part_model.gears import _2807

_OIL_LEVEL_SPECIFICATION = python_net_import(
    "SMT.MastaAPI.SystemModel.PartModel", "OilLevelSpecification"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    from mastapy._private._internal.typing import PathLike

    from mastapy._private.math_utility import _1751
    from mastapy._private.math_utility.measured_data import _1782
    from mastapy._private.utility.enums import _2051

    Self = TypeVar("Self", bound="OilLevelSpecification")
    CastSelf = TypeVar(
        "CastSelf", bound="OilLevelSpecification._Cast_OilLevelSpecification"
    )


__docformat__ = "restructuredtext en"
__all__ = ("OilLevelSpecification",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_OilLevelSpecification:
    """Special nested class for casting OilLevelSpecification to subclasses."""

    __parent__: "OilLevelSpecification"

    @property
    def oil_level_specification(self: "CastSelf") -> "OilLevelSpecification":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class OilLevelSpecification(_0.APIBase):
    """OilLevelSpecification

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _OIL_LEVEL_SPECIFICATION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def extrapolation_options(
        self: "Self",
    ) -> "enum_with_selected_value.EnumWithSelectedValue_ExtrapolationOptions":
        """EnumWithSelectedValue[mastapy.math_utility.ExtrapolationOptions]"""
        temp = pythonnet_property_get(self.wrapped, "ExtrapolationOptions")

        if temp is None:
            return None

        value = enum_with_selected_value.EnumWithSelectedValue_ExtrapolationOptions.wrapped_type()
        return enum_with_selected_value_runtime.create(temp, value)

    @extrapolation_options.setter
    @exception_bridge
    @enforce_parameter_types
    def extrapolation_options(
        self: "Self", value: "_1723.ExtrapolationOptions"
    ) -> None:
        wrapper_type = enum_with_selected_value_runtime.ENUM_WITH_SELECTED_VALUE
        enclosed_type = enum_with_selected_value.EnumWithSelectedValue_ExtrapolationOptions.implicit_type()
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](value)
        pythonnet_property_set(self.wrapped, "ExtrapolationOptions", value)

    @property
    @exception_bridge
    def gear_for_oil_level_reference(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_CylindricalGear":
        """ListWithSelectedItem[mastapy.system_model.part_model.gears.CylindricalGear]"""
        temp = pythonnet_property_get(self.wrapped, "GearForOilLevelReference")

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_CylindricalGear",
        )(temp)

    @gear_for_oil_level_reference.setter
    @exception_bridge
    @enforce_parameter_types
    def gear_for_oil_level_reference(
        self: "Self", value: "_2807.CylindricalGear"
    ) -> None:
        generic_type = (
            list_with_selected_item.ListWithSelectedItem_CylindricalGear.implicit_type()
        )
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "GearForOilLevelReference", value)

    @property
    @exception_bridge
    def oil_level(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "OilLevel")

        if temp is None:
            return 0.0

        return temp

    @oil_level.setter
    @exception_bridge
    @enforce_parameter_types
    def oil_level(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "OilLevel", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def oil_level_reference_datum(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_Datum":
        """ListWithSelectedItem[mastapy.system_model.part_model.Datum]"""
        temp = pythonnet_property_get(self.wrapped, "OilLevelReferenceDatum")

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_Datum",
        )(temp)

    @oil_level_reference_datum.setter
    @exception_bridge
    @enforce_parameter_types
    def oil_level_reference_datum(self: "Self", value: "_2719.Datum") -> None:
        generic_type = (
            list_with_selected_item.ListWithSelectedItem_Datum.implicit_type()
        )
        value = promote_to_list_with_selected_item(value)
        value = conversion.mp_to_pn_smt_list_with_selected_item(
            self, value, generic_type
        )
        pythonnet_property_set(self.wrapped, "OilLevelReferenceDatum", value)

    @property
    @exception_bridge
    def oil_level_specification_method(
        self: "Self",
    ) -> "_2051.PropertySpecificationMethod":
        """mastapy.utility.enums.PropertySpecificationMethod"""
        temp = pythonnet_property_get(self.wrapped, "OilLevelSpecificationMethod")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Utility.Enums.PropertySpecificationMethod"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.utility.enums._2051", "PropertySpecificationMethod"
        )(value)

    @oil_level_specification_method.setter
    @exception_bridge
    @enforce_parameter_types
    def oil_level_specification_method(
        self: "Self", value: "_2051.PropertySpecificationMethod"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Utility.Enums.PropertySpecificationMethod"
        )
        pythonnet_property_set(self.wrapped, "OilLevelSpecificationMethod", value)

    @property
    @exception_bridge
    def oil_level_specified(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "OilLevelSpecified")

        if temp is None:
            return False

        return temp

    @oil_level_specified.setter
    @exception_bridge
    @enforce_parameter_types
    def oil_level_specified(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "OilLevelSpecified",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def oil_level_vs_speed(self: "Self") -> "_1751.Vector2DListAccessor":
        """mastapy.math_utility.Vector2DListAccessor"""
        temp = pythonnet_property_get(self.wrapped, "OilLevelVsSpeed")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @oil_level_vs_speed.setter
    @exception_bridge
    @enforce_parameter_types
    def oil_level_vs_speed(self: "Self", value: "_1751.Vector2DListAccessor") -> None:
        pythonnet_property_set(self.wrapped, "OilLevelVsSpeed", value.wrapped)

    @property
    @exception_bridge
    def oil_level_vs_speed_and_temperature(
        self: "Self",
    ) -> "_1782.GriddedSurfaceAccessor":
        """mastapy.math_utility.measured_data.GriddedSurfaceAccessor"""
        temp = pythonnet_property_get(self.wrapped, "OilLevelVsSpeedAndTemperature")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @oil_level_vs_speed_and_temperature.setter
    @exception_bridge
    @enforce_parameter_types
    def oil_level_vs_speed_and_temperature(
        self: "Self", value: "_1782.GriddedSurfaceAccessor"
    ) -> None:
        pythonnet_property_set(
            self.wrapped, "OilLevelVsSpeedAndTemperature", value.wrapped
        )

    @property
    @exception_bridge
    def use_gear_tip_diameter_for_oil_level_reference(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(
            self.wrapped, "UseGearTipDiameterForOilLevelReference"
        )

        if temp is None:
            return False

        return temp

    @use_gear_tip_diameter_for_oil_level_reference.setter
    @exception_bridge
    @enforce_parameter_types
    def use_gear_tip_diameter_for_oil_level_reference(
        self: "Self", value: "bool"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "UseGearTipDiameterForOilLevelReference",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ReportNames")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    @exception_bridge
    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputDefaultReportTo", file_path)

    @exception_bridge
    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetDefaultReportWithEncodedImages"
        )
        return method_result

    @exception_bridge
    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputActiveReportTo", file_path)

    @exception_bridge
    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "PathLike") -> None:
        """Method does not return.

        Args:
            file_path (PathLike)
        """
        file_path = str(file_path)
        pythonnet_method_call(self.wrapped, "OutputActiveReportAsTextTo", file_path)

    @exception_bridge
    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetActiveReportWithEncodedImages"
        )
        return method_result

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportTo",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsMastaReport",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "PathLike"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (PathLike)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        pythonnet_method_call(
            self.wrapped,
            "OutputNamedReportAsTextTo",
            report_name if report_name else "",
            file_path,
        )

    @exception_bridge
    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = pythonnet_method_call(
            self.wrapped,
            "GetNamedReportWithEncodedImages",
            report_name if report_name else "",
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_OilLevelSpecification":
        """Cast to another type.

        Returns:
            _Cast_OilLevelSpecification
        """
        return _Cast_OilLevelSpecification(self)



"""RollerBearingConicalProfile"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import utility
from mastapy._private.bearings.roller_bearing_profiles import _2176

_ROLLER_BEARING_CONICAL_PROFILE = python_net_import(
    "SMT.MastaAPI.Bearings.RollerBearingProfiles", "RollerBearingConicalProfile"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="RollerBearingConicalProfile")
    CastSelf = TypeVar(
        "CastSelf",
        bound="RollerBearingConicalProfile._Cast_RollerBearingConicalProfile",
    )


__docformat__ = "restructuredtext en"
__all__ = ("RollerBearingConicalProfile",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_RollerBearingConicalProfile:
    """Special nested class for casting RollerBearingConicalProfile to subclasses."""

    __parent__: "RollerBearingConicalProfile"

    @property
    def roller_bearing_profile(self: "CastSelf") -> "_2176.RollerBearingProfile":
        return self.__parent__._cast(_2176.RollerBearingProfile)

    @property
    def roller_bearing_conical_profile(
        self: "CastSelf",
    ) -> "RollerBearingConicalProfile":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class RollerBearingConicalProfile(_2176.RollerBearingProfile):
    """RollerBearingConicalProfile

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ROLLER_BEARING_CONICAL_PROFILE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def cone_angle(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "ConeAngle")

        if temp is None:
            return 0.0

        return temp

    @cone_angle.setter
    @exception_bridge
    @enforce_parameter_types
    def cone_angle(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "ConeAngle", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def deviation_offset(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "DeviationOffset")

        if temp is None:
            return 0.0

        return temp

    @deviation_offset.setter
    @exception_bridge
    @enforce_parameter_types
    def deviation_offset(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "DeviationOffset", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def deviation_at_end_of_component(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "DeviationAtEndOfComponent")

        if temp is None:
            return 0.0

        return temp

    @deviation_at_end_of_component.setter
    @exception_bridge
    @enforce_parameter_types
    def deviation_at_end_of_component(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "DeviationAtEndOfComponent",
            float(value) if value is not None else 0.0,
        )

    @property
    def cast_to(self: "Self") -> "_Cast_RollerBearingConicalProfile":
        """Cast to another type.

        Returns:
            _Cast_RollerBearingConicalProfile
        """
        return _Cast_RollerBearingConicalProfile(self)



"""ProfileToothDrawingMethod"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_PROFILE_TOOTH_DRAWING_METHOD = python_net_import(
    "SMT.MastaAPI.SystemModel.PartModel.Gears", "ProfileToothDrawingMethod"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ProfileToothDrawingMethod")
    CastSelf = TypeVar(
        "CastSelf", bound="ProfileToothDrawingMethod._Cast_ProfileToothDrawingMethod"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ProfileToothDrawingMethod",)


class ProfileToothDrawingMethod(Enum):
    """ProfileToothDrawingMethod

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _PROFILE_TOOTH_DRAWING_METHOD

    DRAW_TO_TIP_DIAMETER = 0
    DRAW_TO_ROOT_DIAMETER = 1
    DRAW_TO_REFERENCE_DIAMETER = 2
    DRAW_TO_ROOT_AND_TIP_DIAMETER = 3
    DONT_DRAW_GEAR = 4


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


ProfileToothDrawingMethod.__setattr__ = __enum_setattr
ProfileToothDrawingMethod.__delattr__ = __enum_delattr



"""ProgramSettings"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import overridable
from mastapy._private.utility import _1820

_PROGRAM_SETTINGS = python_net_import("SMT.MastaAPI.Utility", "ProgramSettings")

if TYPE_CHECKING:
    from typing import Any, Tuple, Type, TypeVar, Union

    from mastapy._private.utility import _1821

    Self = TypeVar("Self", bound="ProgramSettings")
    CastSelf = TypeVar("CastSelf", bound="ProgramSettings._Cast_ProgramSettings")


__docformat__ = "restructuredtext en"
__all__ = ("ProgramSettings",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ProgramSettings:
    """Special nested class for casting ProgramSettings to subclasses."""

    __parent__: "ProgramSettings"

    @property
    def per_machine_settings(self: "CastSelf") -> "_1820.PerMachineSettings":
        return self.__parent__._cast(_1820.PerMachineSettings)

    @property
    def persistent_singleton(self: "CastSelf") -> "_1821.PersistentSingleton":
        from mastapy._private.utility import _1821

        return self.__parent__._cast(_1821.PersistentSingleton)

    @property
    def program_settings(self: "CastSelf") -> "ProgramSettings":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class ProgramSettings(_1820.PerMachineSettings):
    """ProgramSettings

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _PROGRAM_SETTINGS

    class CheckForNewerVersionOption(Enum):
        """CheckForNewerVersionOption is a nested enum."""

        @classmethod
        def type_(cls) -> "Type":
            return _PROGRAM_SETTINGS.CheckForNewerVersionOption

        ASK_ON_STARTUP = 0
        YES = 1
        NO = 2

    def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
        raise AttributeError("Cannot set the attributes of an Enum.") from None

    def __enum_delattr(self: "Self", attr: str) -> None:
        raise AttributeError("Cannot delete the attributes of an Enum.") from None

    CheckForNewerVersionOption.__setattr__ = __enum_setattr
    CheckForNewerVersionOption.__delattr__ = __enum_delattr

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def two_dcad_guide_model_autosave_size_limit(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(
            self.wrapped, "TwoDCADGuideModelAutosaveSizeLimit"
        )

        if temp is None:
            return 0.0

        return temp

    @two_dcad_guide_model_autosave_size_limit.setter
    @exception_bridge
    @enforce_parameter_types
    def two_dcad_guide_model_autosave_size_limit(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "TwoDCADGuideModelAutosaveSizeLimit",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def allow_multithreading(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "AllowMultithreading")

        if temp is None:
            return False

        return temp

    @allow_multithreading.setter
    @exception_bridge
    @enforce_parameter_types
    def allow_multithreading(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "AllowMultithreading",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def ask_for_part_names_in_the_2d_view(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "AskForPartNamesInThe2DView")

        if temp is None:
            return False

        return temp

    @ask_for_part_names_in_the_2d_view.setter
    @exception_bridge
    @enforce_parameter_types
    def ask_for_part_names_in_the_2d_view(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "AskForPartNamesInThe2DView",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def auto_return_licences_inactivity_interval_minutes(
        self: "Self",
    ) -> "overridable.Overridable_int":
        """Overridable[int]"""
        temp = pythonnet_property_get(
            self.wrapped, "AutoReturnLicencesInactivityIntervalMinutes"
        )

        if temp is None:
            return 0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_int"
        )(temp)

    @auto_return_licences_inactivity_interval_minutes.setter
    @exception_bridge
    @enforce_parameter_types
    def auto_return_licences_inactivity_interval_minutes(
        self: "Self", value: "Union[int, Tuple[int, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0, is_overridden
        )
        pythonnet_property_set(
            self.wrapped, "AutoReturnLicencesInactivityIntervalMinutes", value
        )

    @property
    @exception_bridge
    def autosave_directory(self: "Self") -> "str":
        """str

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "AutosaveDirectory")

        if temp is None:
            return ""

        return temp

    @property
    @exception_bridge
    def autosave_interval_minutes(self: "Self") -> "overridable.Overridable_int":
        """Overridable[int]"""
        temp = pythonnet_property_get(self.wrapped, "AutosaveIntervalMinutes")

        if temp is None:
            return 0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_int"
        )(temp)

    @autosave_interval_minutes.setter
    @exception_bridge
    @enforce_parameter_types
    def autosave_interval_minutes(
        self: "Self", value: "Union[int, Tuple[int, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "AutosaveIntervalMinutes", value)

    @property
    @exception_bridge
    def check_for_new_version_on_startup(
        self: "Self",
    ) -> "ProgramSettings.CheckForNewerVersionOption":
        """mastapy.utility.ProgramSettings.CheckForNewerVersionOption"""
        temp = pythonnet_property_get(self.wrapped, "CheckForNewVersionOnStartup")

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Utility.ProgramSettings+CheckForNewerVersionOption"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.utility.ProgramSettings.ProgramSettings",
            "CheckForNewerVersionOption",
        )(value)

    @check_for_new_version_on_startup.setter
    @exception_bridge
    @enforce_parameter_types
    def check_for_new_version_on_startup(
        self: "Self", value: "ProgramSettings.CheckForNewerVersionOption"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Utility.ProgramSettings+CheckForNewerVersionOption"
        )
        pythonnet_property_set(self.wrapped, "CheckForNewVersionOnStartup", value)

    @property
    @exception_bridge
    def confirm_exit(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "ConfirmExit")

        if temp is None:
            return False

        return temp

    @confirm_exit.setter
    @exception_bridge
    @enforce_parameter_types
    def confirm_exit(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "ConfirmExit", bool(value) if value is not None else False
        )

    @property
    @exception_bridge
    def font_size(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "FontSize")

        if temp is None:
            return 0.0

        return temp

    @font_size.setter
    @exception_bridge
    @enforce_parameter_types
    def font_size(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "FontSize", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def include_overridable_property_source_information(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(
            self.wrapped, "IncludeOverridablePropertySourceInformation"
        )

        if temp is None:
            return False

        return temp

    @include_overridable_property_source_information.setter
    @exception_bridge
    @enforce_parameter_types
    def include_overridable_property_source_information(
        self: "Self", value: "bool"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "IncludeOverridablePropertySourceInformation",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def is_view_focus_linked_to_3d_by_default(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "IsViewFocusLinkedTo3DByDefault")

        if temp is None:
            return False

        return temp

    @is_view_focus_linked_to_3d_by_default.setter
    @exception_bridge
    @enforce_parameter_types
    def is_view_focus_linked_to_3d_by_default(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "IsViewFocusLinkedTo3DByDefault",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def load_saved_operation_mode_and_selection(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(
            self.wrapped, "LoadSavedOperationModeAndSelection"
        )

        if temp is None:
            return False

        return temp

    @load_saved_operation_mode_and_selection.setter
    @exception_bridge
    @enforce_parameter_types
    def load_saved_operation_mode_and_selection(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "LoadSavedOperationModeAndSelection",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def maximum_number_of_files_to_store_in_history(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(
            self.wrapped, "MaximumNumberOfFilesToStoreInHistory"
        )

        if temp is None:
            return 0

        return temp

    @maximum_number_of_files_to_store_in_history.setter
    @exception_bridge
    @enforce_parameter_types
    def maximum_number_of_files_to_store_in_history(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped,
            "MaximumNumberOfFilesToStoreInHistory",
            int(value) if value is not None else 0,
        )

    @property
    @exception_bridge
    def maximum_number_of_threads_for_large_operations(
        self: "Self",
    ) -> "overridable.Overridable_int":
        """Overridable[int]"""
        temp = pythonnet_property_get(
            self.wrapped, "MaximumNumberOfThreadsForLargeOperations"
        )

        if temp is None:
            return 0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_int"
        )(temp)

    @maximum_number_of_threads_for_large_operations.setter
    @exception_bridge
    @enforce_parameter_types
    def maximum_number_of_threads_for_large_operations(
        self: "Self", value: "Union[int, Tuple[int, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0, is_overridden
        )
        pythonnet_property_set(
            self.wrapped, "MaximumNumberOfThreadsForLargeOperations", value
        )

    @property
    @exception_bridge
    def maximum_number_of_threads_for_mathematically_intensive_operations(
        self: "Self",
    ) -> "overridable.Overridable_int":
        """Overridable[int]"""
        temp = pythonnet_property_get(
            self.wrapped, "MaximumNumberOfThreadsForMathematicallyIntensiveOperations"
        )

        if temp is None:
            return 0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_int"
        )(temp)

    @maximum_number_of_threads_for_mathematically_intensive_operations.setter
    @exception_bridge
    @enforce_parameter_types
    def maximum_number_of_threads_for_mathematically_intensive_operations(
        self: "Self", value: "Union[int, Tuple[int, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0, is_overridden
        )
        pythonnet_property_set(
            self.wrapped,
            "MaximumNumberOfThreadsForMathematicallyIntensiveOperations",
            value,
        )

    @property
    @exception_bridge
    def maximum_number_of_undo_items(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(self.wrapped, "MaximumNumberOfUndoItems")

        if temp is None:
            return 0

        return temp

    @maximum_number_of_undo_items.setter
    @exception_bridge
    @enforce_parameter_types
    def maximum_number_of_undo_items(self: "Self", value: "int") -> None:
        pythonnet_property_set(
            self.wrapped,
            "MaximumNumberOfUndoItems",
            int(value) if value is not None else 0,
        )

    @property
    @exception_bridge
    def number_of_cpu_cores(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NumberOfCPUCores")

        if temp is None:
            return 0

        return temp

    @property
    @exception_bridge
    def number_of_cpu_threads(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "NumberOfCPUThreads")

        if temp is None:
            return 0

        return temp

    @property
    @exception_bridge
    def number_of_connections_to_show_when_multi_selecting(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(
            self.wrapped, "NumberOfConnectionsToShowWhenMultiSelecting"
        )

        if temp is None:
            return 0

        return temp

    @number_of_connections_to_show_when_multi_selecting.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_connections_to_show_when_multi_selecting(
        self: "Self", value: "int"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "NumberOfConnectionsToShowWhenMultiSelecting",
            int(value) if value is not None else 0,
        )

    @property
    @exception_bridge
    def number_of_days_of_advance_warning_for_expiring_features(self: "Self") -> "int":
        """int"""
        temp = pythonnet_property_get(
            self.wrapped, "NumberOfDaysOfAdvanceWarningForExpiringFeatures"
        )

        if temp is None:
            return 0

        return temp

    @number_of_days_of_advance_warning_for_expiring_features.setter
    @exception_bridge
    @enforce_parameter_types
    def number_of_days_of_advance_warning_for_expiring_features(
        self: "Self", value: "int"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "NumberOfDaysOfAdvanceWarningForExpiringFeatures",
            int(value) if value is not None else 0,
        )

    @property
    @exception_bridge
    def override_font(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get(self.wrapped, "OverrideFont")

        if temp is None:
            return ""

        return temp

    @override_font.setter
    @exception_bridge
    @enforce_parameter_types
    def override_font(self: "Self", value: "str") -> None:
        pythonnet_property_set(
            self.wrapped, "OverrideFont", str(value) if value is not None else ""
        )

    @property
    @exception_bridge
    def save_driva_results_by_default(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "SaveDRIVAResultsByDefault")

        if temp is None:
            return False

        return temp

    @save_driva_results_by_default.setter
    @exception_bridge
    @enforce_parameter_types
    def save_driva_results_by_default(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "SaveDRIVAResultsByDefault",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def show_drawing_numbers_in_tree_view(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "ShowDrawingNumbersInTreeView")

        if temp is None:
            return False

        return temp

    @show_drawing_numbers_in_tree_view.setter
    @exception_bridge
    @enforce_parameter_types
    def show_drawing_numbers_in_tree_view(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "ShowDrawingNumbersInTreeView",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def show_number_of_teeth_with_gear_set_names(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "ShowNumberOfTeethWithGearSetNames")

        if temp is None:
            return False

        return temp

    @show_number_of_teeth_with_gear_set_names.setter
    @exception_bridge
    @enforce_parameter_types
    def show_number_of_teeth_with_gear_set_names(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "ShowNumberOfTeethWithGearSetNames",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def show_shaft_mounted_components(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "ShowShaftMountedComponents")

        if temp is None:
            return False

        return temp

    @show_shaft_mounted_components.setter
    @exception_bridge
    @enforce_parameter_types
    def show_shaft_mounted_components(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "ShowShaftMountedComponents",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def show_user_interface_hints(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "ShowUserInterfaceHints")

        if temp is None:
            return False

        return temp

    @show_user_interface_hints.setter
    @exception_bridge
    @enforce_parameter_types
    def show_user_interface_hints(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "ShowUserInterfaceHints",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def use_background_saving(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseBackgroundSaving")

        if temp is None:
            return False

        return temp

    @use_background_saving.setter
    @exception_bridge
    @enforce_parameter_types
    def use_background_saving(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "UseBackgroundSaving",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def use_compression_for_masta_files(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseCompressionForMASTAFiles")

        if temp is None:
            return False

        return temp

    @use_compression_for_masta_files.setter
    @exception_bridge
    @enforce_parameter_types
    def use_compression_for_masta_files(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "UseCompressionForMASTAFiles",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def use_default_autosave_directory(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseDefaultAutosaveDirectory")

        if temp is None:
            return False

        return temp

    @use_default_autosave_directory.setter
    @exception_bridge
    @enforce_parameter_types
    def use_default_autosave_directory(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "UseDefaultAutosaveDirectory",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def use_standard_dialog_for_file_open(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseStandardDialogForFileOpen")

        if temp is None:
            return False

        return temp

    @use_standard_dialog_for_file_open.setter
    @exception_bridge
    @enforce_parameter_types
    def use_standard_dialog_for_file_open(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "UseStandardDialogForFileOpen",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def use_standard_dialog_for_file_save(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseStandardDialogForFileSave")

        if temp is None:
            return False

        return temp

    @use_standard_dialog_for_file_save.setter
    @exception_bridge
    @enforce_parameter_types
    def use_standard_dialog_for_file_save(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped,
            "UseStandardDialogForFileSave",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def user_name(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get(self.wrapped, "UserName")

        if temp is None:
            return ""

        return temp

    @user_name.setter
    @exception_bridge
    @enforce_parameter_types
    def user_name(self: "Self", value: "str") -> None:
        pythonnet_property_set(
            self.wrapped, "UserName", str(value) if value is not None else ""
        )

    @property
    @exception_bridge
    def user_defined_autosave_directory(self: "Self") -> "str":
        """str"""
        temp = pythonnet_property_get(self.wrapped, "UserDefinedAutosaveDirectory")

        if temp is None:
            return ""

        return temp

    @user_defined_autosave_directory.setter
    @exception_bridge
    @enforce_parameter_types
    def user_defined_autosave_directory(self: "Self", value: "str") -> None:
        pythonnet_property_set(
            self.wrapped,
            "UserDefinedAutosaveDirectory",
            str(value) if value is not None else "",
        )

    @exception_bridge
    def clear_mru_entries(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "ClearMRUEntries")

    @exception_bridge
    def select_autosave_directory(self: "Self") -> None:
        """Method does not return."""
        pythonnet_method_call(self.wrapped, "SelectAutosaveDirectory")

    @property
    def cast_to(self: "Self") -> "_Cast_ProgramSettings":
        """Cast to another type.

        Returns:
            _Cast_ProgramSettings
        """
        return _Cast_ProgramSettings(self)



"""ConnectedComponentType"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_CONNECTED_COMPONENT_TYPE = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.HarmonicAnalyses.Results",
    "ConnectedComponentType",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="ConnectedComponentType")
    CastSelf = TypeVar(
        "CastSelf", bound="ConnectedComponentType._Cast_ConnectedComponentType"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConnectedComponentType",)


class ConnectedComponentType(Enum):
    """ConnectedComponentType

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _CONNECTED_COMPONENT_TYPE

    ALL = 0
    BEARING = 1
    POINT_LOAD = 2
    POWER_LOAD = 3
    SHAFTHUB_CONNECTION = 4
    GEAR_MESH = 5
    UNCONNECTED = 6


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


ConnectedComponentType.__setattr__ = __enum_setattr
ConnectedComponentType.__delattr__ = __enum_delattr



"""LeadModification"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_property_get,
    pythonnet_property_set,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from PIL.Image import Image

from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.gears.micro_geometry import _692

_LEAD_MODIFICATION = python_net_import(
    "SMT.MastaAPI.Gears.MicroGeometry", "LeadModification"
)

if TYPE_CHECKING:
    from typing import Any, Optional, Type, TypeVar

    from mastapy._private.gears.gear_designs.conical.micro_geometry import _1320
    from mastapy._private.gears.gear_designs.cylindrical.micro_geometry import (
        _1232,
        _1233,
    )
    from mastapy._private.math_utility import _1751

    Self = TypeVar("Self", bound="LeadModification")
    CastSelf = TypeVar("CastSelf", bound="LeadModification._Cast_LeadModification")


__docformat__ = "restructuredtext en"
__all__ = ("LeadModification",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_LeadModification:
    """Special nested class for casting LeadModification to subclasses."""

    __parent__: "LeadModification"

    @property
    def modification(self: "CastSelf") -> "_692.Modification":
        return self.__parent__._cast(_692.Modification)

    @property
    def cylindrical_gear_lead_modification(
        self: "CastSelf",
    ) -> "_1232.CylindricalGearLeadModification":
        from mastapy._private.gears.gear_designs.cylindrical.micro_geometry import _1232

        return self.__parent__._cast(_1232.CylindricalGearLeadModification)

    @property
    def cylindrical_gear_lead_modification_at_profile_position(
        self: "CastSelf",
    ) -> "_1233.CylindricalGearLeadModificationAtProfilePosition":
        from mastapy._private.gears.gear_designs.cylindrical.micro_geometry import _1233

        return self.__parent__._cast(
            _1233.CylindricalGearLeadModificationAtProfilePosition
        )

    @property
    def conical_gear_lead_modification(
        self: "CastSelf",
    ) -> "_1320.ConicalGearLeadModification":
        from mastapy._private.gears.gear_designs.conical.micro_geometry import _1320

        return self.__parent__._cast(_1320.ConicalGearLeadModification)

    @property
    def lead_modification(self: "CastSelf") -> "LeadModification":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class LeadModification(_692.Modification):
    """LeadModification

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _LEAD_MODIFICATION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def cad_composed_drawing(self: "Self") -> "Image":
        """Image

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "CADComposedDrawing")

        if temp is None:
            return None

        value = conversion.pn_to_mp_smt_bitmap(temp)

        if value is None:
            return None

        return value

    @property
    @exception_bridge
    def crowning_relief(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "CrowningRelief")

        if temp is None:
            return 0.0

        return temp

    @crowning_relief.setter
    @exception_bridge
    @enforce_parameter_types
    def crowning_relief(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "CrowningRelief", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def evaluation_left_limit_factor(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "EvaluationLeftLimitFactor")

        if temp is None:
            return 0.0

        return temp

    @evaluation_left_limit_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def evaluation_left_limit_factor(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "EvaluationLeftLimitFactor",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def evaluation_of_linear_left_relief_factor(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(
            self.wrapped, "EvaluationOfLinearLeftReliefFactor"
        )

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_linear_left_relief_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def evaluation_of_linear_left_relief_factor(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "EvaluationOfLinearLeftReliefFactor",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def evaluation_of_linear_right_relief_factor(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(
            self.wrapped, "EvaluationOfLinearRightReliefFactor"
        )

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_linear_right_relief_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def evaluation_of_linear_right_relief_factor(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "EvaluationOfLinearRightReliefFactor",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def evaluation_of_linear_side_relief_factor(self: "Self") -> "Optional[float]":
        """Optional[float]"""
        temp = pythonnet_property_get(
            self.wrapped, "EvaluationOfLinearSideReliefFactor"
        )

        if temp is None:
            return None

        return temp

    @evaluation_of_linear_side_relief_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def evaluation_of_linear_side_relief_factor(
        self: "Self", value: "Optional[float]"
    ) -> None:
        pythonnet_property_set(
            self.wrapped, "EvaluationOfLinearSideReliefFactor", value
        )

    @property
    @exception_bridge
    def evaluation_of_parabolic_left_relief_factor(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(
            self.wrapped, "EvaluationOfParabolicLeftReliefFactor"
        )

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_parabolic_left_relief_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def evaluation_of_parabolic_left_relief_factor(
        self: "Self", value: "float"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "EvaluationOfParabolicLeftReliefFactor",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def evaluation_of_parabolic_right_relief_factor(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(
            self.wrapped, "EvaluationOfParabolicRightReliefFactor"
        )

        if temp is None:
            return 0.0

        return temp

    @evaluation_of_parabolic_right_relief_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def evaluation_of_parabolic_right_relief_factor(
        self: "Self", value: "float"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "EvaluationOfParabolicRightReliefFactor",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def evaluation_of_parabolic_side_relief_factor(self: "Self") -> "Optional[float]":
        """Optional[float]"""
        temp = pythonnet_property_get(
            self.wrapped, "EvaluationOfParabolicSideReliefFactor"
        )

        if temp is None:
            return None

        return temp

    @evaluation_of_parabolic_side_relief_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def evaluation_of_parabolic_side_relief_factor(
        self: "Self", value: "Optional[float]"
    ) -> None:
        pythonnet_property_set(
            self.wrapped, "EvaluationOfParabolicSideReliefFactor", value
        )

    @property
    @exception_bridge
    def evaluation_right_limit_factor(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "EvaluationRightLimitFactor")

        if temp is None:
            return 0.0

        return temp

    @evaluation_right_limit_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def evaluation_right_limit_factor(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "EvaluationRightLimitFactor",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def evaluation_side_limit_factor(self: "Self") -> "Optional[float]":
        """Optional[float]"""
        temp = pythonnet_property_get(self.wrapped, "EvaluationSideLimitFactor")

        if temp is None:
            return None

        return temp

    @evaluation_side_limit_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def evaluation_side_limit_factor(self: "Self", value: "Optional[float]") -> None:
        pythonnet_property_set(self.wrapped, "EvaluationSideLimitFactor", value)

    @property
    @exception_bridge
    def linear_left_relief(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "LinearLeftRelief")

        if temp is None:
            return 0.0

        return temp

    @linear_left_relief.setter
    @exception_bridge
    @enforce_parameter_types
    def linear_left_relief(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "LinearLeftRelief", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def linear_relief(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "LinearRelief")

        if temp is None:
            return 0.0

        return temp

    @linear_relief.setter
    @exception_bridge
    @enforce_parameter_types
    def linear_relief(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped, "LinearRelief", float(value) if value is not None else 0.0
        )

    @property
    @exception_bridge
    def linear_right_relief(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "LinearRightRelief")

        if temp is None:
            return 0.0

        return temp

    @linear_right_relief.setter
    @exception_bridge
    @enforce_parameter_types
    def linear_right_relief(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "LinearRightRelief",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def linear_side_relief(self: "Self") -> "Optional[float]":
        """Optional[float]"""
        temp = pythonnet_property_get(self.wrapped, "LinearSideRelief")

        if temp is None:
            return None

        return temp

    @linear_side_relief.setter
    @exception_bridge
    @enforce_parameter_types
    def linear_side_relief(self: "Self", value: "Optional[float]") -> None:
        pythonnet_property_set(self.wrapped, "LinearSideRelief", value)

    @property
    @exception_bridge
    def measured_data(self: "Self") -> "_1751.Vector2DListAccessor":
        """mastapy.math_utility.Vector2DListAccessor"""
        temp = pythonnet_property_get(self.wrapped, "MeasuredData")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @measured_data.setter
    @exception_bridge
    @enforce_parameter_types
    def measured_data(self: "Self", value: "_1751.Vector2DListAccessor") -> None:
        pythonnet_property_set(self.wrapped, "MeasuredData", value.wrapped)

    @property
    @exception_bridge
    def parabolic_left_relief(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "ParabolicLeftRelief")

        if temp is None:
            return 0.0

        return temp

    @parabolic_left_relief.setter
    @exception_bridge
    @enforce_parameter_types
    def parabolic_left_relief(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "ParabolicLeftRelief",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def parabolic_right_relief(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "ParabolicRightRelief")

        if temp is None:
            return 0.0

        return temp

    @parabolic_right_relief.setter
    @exception_bridge
    @enforce_parameter_types
    def parabolic_right_relief(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "ParabolicRightRelief",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def parabolic_side_relief(self: "Self") -> "Optional[float]":
        """Optional[float]"""
        temp = pythonnet_property_get(self.wrapped, "ParabolicSideRelief")

        if temp is None:
            return None

        return temp

    @parabolic_side_relief.setter
    @exception_bridge
    @enforce_parameter_types
    def parabolic_side_relief(self: "Self", value: "Optional[float]") -> None:
        pythonnet_property_set(self.wrapped, "ParabolicSideRelief", value)

    @property
    @exception_bridge
    def start_of_linear_left_relief_factor(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "StartOfLinearLeftReliefFactor")

        if temp is None:
            return 0.0

        return temp

    @start_of_linear_left_relief_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def start_of_linear_left_relief_factor(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "StartOfLinearLeftReliefFactor",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def start_of_linear_right_relief_factor(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "StartOfLinearRightReliefFactor")

        if temp is None:
            return 0.0

        return temp

    @start_of_linear_right_relief_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def start_of_linear_right_relief_factor(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "StartOfLinearRightReliefFactor",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def start_of_linear_side_relief_factor(self: "Self") -> "Optional[float]":
        """Optional[float]"""
        temp = pythonnet_property_get(self.wrapped, "StartOfLinearSideReliefFactor")

        if temp is None:
            return None

        return temp

    @start_of_linear_side_relief_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def start_of_linear_side_relief_factor(
        self: "Self", value: "Optional[float]"
    ) -> None:
        pythonnet_property_set(self.wrapped, "StartOfLinearSideReliefFactor", value)

    @property
    @exception_bridge
    def start_of_parabolic_left_relief_factor(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "StartOfParabolicLeftReliefFactor")

        if temp is None:
            return 0.0

        return temp

    @start_of_parabolic_left_relief_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def start_of_parabolic_left_relief_factor(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "StartOfParabolicLeftReliefFactor",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def start_of_parabolic_right_relief_factor(self: "Self") -> "float":
        """float"""
        temp = pythonnet_property_get(self.wrapped, "StartOfParabolicRightReliefFactor")

        if temp is None:
            return 0.0

        return temp

    @start_of_parabolic_right_relief_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def start_of_parabolic_right_relief_factor(self: "Self", value: "float") -> None:
        pythonnet_property_set(
            self.wrapped,
            "StartOfParabolicRightReliefFactor",
            float(value) if value is not None else 0.0,
        )

    @property
    @exception_bridge
    def start_of_parabolic_side_relief_factor(self: "Self") -> "Optional[float]":
        """Optional[float]"""
        temp = pythonnet_property_get(self.wrapped, "StartOfParabolicSideReliefFactor")

        if temp is None:
            return None

        return temp

    @start_of_parabolic_side_relief_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def start_of_parabolic_side_relief_factor(
        self: "Self", value: "Optional[float]"
    ) -> None:
        pythonnet_property_set(self.wrapped, "StartOfParabolicSideReliefFactor", value)

    @property
    @exception_bridge
    def use_measured_data(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(self.wrapped, "UseMeasuredData")

        if temp is None:
            return False

        return temp

    @use_measured_data.setter
    @exception_bridge
    @enforce_parameter_types
    def use_measured_data(self: "Self", value: "bool") -> None:
        pythonnet_property_set(
            self.wrapped, "UseMeasuredData", bool(value) if value is not None else False
        )

    @property
    def cast_to(self: "Self") -> "_Cast_LeadModification":
        """Cast to another type.

        Returns:
            _Cast_LeadModification
        """
        return _Cast_LeadModification(self)



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.utility.vectors._2072 import PlaneVectorFieldData
    from mastapy._private.utility.vectors._2073 import PlaneScalarFieldData
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.utility.vectors._2072": ["PlaneVectorFieldData"],
        "_private.utility.vectors._2073": ["PlaneScalarFieldData"],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "PlaneVectorFieldData",
    "PlaneScalarFieldData",
)



"""MeasurementTypeExtensions"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import conversion

_MEASUREMENT_TYPE_EXTENSIONS = python_net_import(
    "SMT.MastaAPIUtility.UnitsAndMeasurements", "MeasurementTypeExtensions"
)

if TYPE_CHECKING:
    from typing import Any, NoReturn, Type

    from mastapy._private.units_and_measurements import _7959


__docformat__ = "restructuredtext en"
__all__ = ("MeasurementTypeExtensions",)


class MeasurementTypeExtensions:
    """MeasurementTypeExtensions

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _MEASUREMENT_TYPE_EXTENSIONS

    def __new__(
        cls: "Type[MeasurementTypeExtensions]", *args: "Any", **kwargs: "Any"
    ) -> "NoReturn":
        """Override of the new magic method.

        Note:
            This class cannot be instantiated and this method will always throw an
            exception.

        Args:
            cls (Type[MeasurementTypeExtensions]: The class to instantiate.
            *args (Any): Arguments.
            **kwargs (Any): Keyword arguments.

        Returns:
            NoReturn
        """
        raise TypeError("Class cannot be instantiated. Please use statically.")

    @staticmethod
    @exception_bridge
    @enforce_parameter_types
    def is_unmeasurable(measurement_type: "_7959.MeasurementType") -> "bool":
        """bool

        Args:
            measurement_type (mastapy.units_and_measurements.MeasurementType)
        """
        measurement_type = conversion.mp_to_pn_enum(
            measurement_type, "SMT.MastaAPIUtility.UnitsAndMeasurements.MeasurementType"
        )
        method_result = pythonnet_method_call(
            MeasurementTypeExtensions.TYPE, "IsUnmeasurable", measurement_type
        )
        return method_result

    @staticmethod
    @exception_bridge
    @enforce_parameter_types
    def is_angle(measurement_type: "_7959.MeasurementType") -> "bool":
        """bool

        Args:
            measurement_type (mastapy.units_and_measurements.MeasurementType)
        """
        measurement_type = conversion.mp_to_pn_enum(
            measurement_type, "SMT.MastaAPIUtility.UnitsAndMeasurements.MeasurementType"
        )
        method_result = pythonnet_method_call(
            MeasurementTypeExtensions.TYPE, "IsAngle", measurement_type
        )
        return method_result

    @staticmethod
    @exception_bridge
    @enforce_parameter_types
    def is_root_power_quantity(measurement_type: "_7959.MeasurementType") -> "bool":
        """bool

        Args:
            measurement_type (mastapy.units_and_measurements.MeasurementType)
        """
        measurement_type = conversion.mp_to_pn_enum(
            measurement_type, "SMT.MastaAPIUtility.UnitsAndMeasurements.MeasurementType"
        )
        method_result = pythonnet_method_call(
            MeasurementTypeExtensions.TYPE, "IsRootPowerQuantity", measurement_type
        )
        return method_result



"""CylindricalGearMeshLoadCase"""

from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.exception_bridge import exception_bridge
from mastapy._private._internal.exceptions import CastException
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private._internal.python_net import (
    python_net_import,
    pythonnet_method_call,
    pythonnet_property_get,
    pythonnet_property_get_with_method,
    pythonnet_property_set,
    pythonnet_property_set_with_method,
)
from mastapy._private._internal.type_enforcement import enforce_parameter_types

from mastapy._private._internal import (
    constructor,
    conversion,
    overridable_enum_runtime,
    utility,
)
from mastapy._private._internal.implicit import overridable
from mastapy._private.gears import _443, _449, _450, _451
from mastapy._private.gears.rating.cylindrical.iso6336 import _623
from mastapy._private.system_model.analyses_and_results.static_loads import _7815

_DATABASE_WITH_SELECTED_ITEM = python_net_import(
    "SMT.MastaAPI.UtilityGUI.Databases", "DatabaseWithSelectedItem"
)
_CYLINDRICAL_GEAR_MESH_LOAD_CASE = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.StaticLoads",
    "CylindricalGearMeshLoadCase",
)

if TYPE_CHECKING:
    from typing import Any, List, Tuple, Type, TypeVar, Union

    from mastapy._private.gears import _446
    from mastapy._private.gears.materials import _721
    from mastapy._private.system_model.analyses_and_results import _2942, _2944, _2946
    from mastapy._private.system_model.analyses_and_results.static_loads import (
        _7772,
        _7787,
        _7834,
    )
    from mastapy._private.system_model.connections_and_sockets.gears import _2569

    Self = TypeVar("Self", bound="CylindricalGearMeshLoadCase")
    CastSelf = TypeVar(
        "CastSelf",
        bound="CylindricalGearMeshLoadCase._Cast_CylindricalGearMeshLoadCase",
    )


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalGearMeshLoadCase",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CylindricalGearMeshLoadCase:
    """Special nested class for casting CylindricalGearMeshLoadCase to subclasses."""

    __parent__: "CylindricalGearMeshLoadCase"

    @property
    def gear_mesh_load_case(self: "CastSelf") -> "_7815.GearMeshLoadCase":
        return self.__parent__._cast(_7815.GearMeshLoadCase)

    @property
    def inter_mountable_component_connection_load_case(
        self: "CastSelf",
    ) -> "_7834.InterMountableComponentConnectionLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7834,
        )

        return self.__parent__._cast(_7834.InterMountableComponentConnectionLoadCase)

    @property
    def connection_load_case(self: "CastSelf") -> "_7772.ConnectionLoadCase":
        from mastapy._private.system_model.analyses_and_results.static_loads import (
            _7772,
        )

        return self.__parent__._cast(_7772.ConnectionLoadCase)

    @property
    def connection_analysis(self: "CastSelf") -> "_2942.ConnectionAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2942

        return self.__parent__._cast(_2942.ConnectionAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2946.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2946

        return self.__parent__._cast(_2946.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2944.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2944

        return self.__parent__._cast(_2944.DesignEntityAnalysis)

    @property
    def cylindrical_gear_mesh_load_case(
        self: "CastSelf",
    ) -> "CylindricalGearMeshLoadCase":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True, eq=False)
class CylindricalGearMeshLoadCase(_7815.GearMeshLoadCase):
    """CylindricalGearMeshLoadCase

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYLINDRICAL_GEAR_MESH_LOAD_CASE

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    @exception_bridge
    def application_factor(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "ApplicationFactor")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @application_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def application_factor(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "ApplicationFactor", value)

    @property
    @exception_bridge
    def change_in_centre_distance_due_to_housing_thermal_effects(
        self: "Self",
    ) -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ChangeInCentreDistanceDueToHousingThermalEffects"
        )

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def do_profile_modifications_compensate_for_the_deflections_at_actual_load(
        self: "Self",
    ) -> "bool":
        """bool"""
        temp = pythonnet_property_get(
            self.wrapped,
            "DoProfileModificationsCompensateForTheDeflectionsAtActualLoad",
        )

        if temp is None:
            return False

        return temp

    @do_profile_modifications_compensate_for_the_deflections_at_actual_load.setter
    @exception_bridge
    @enforce_parameter_types
    def do_profile_modifications_compensate_for_the_deflections_at_actual_load(
        self: "Self", value: "bool"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "DoProfileModificationsCompensateForTheDeflectionsAtActualLoad",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def dynamic_factor(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "DynamicFactor")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @dynamic_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def dynamic_factor(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "DynamicFactor", value)

    @property
    @exception_bridge
    def face_load_factor_bending(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "FaceLoadFactorBending")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @face_load_factor_bending.setter
    @exception_bridge
    @enforce_parameter_types
    def face_load_factor_bending(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "FaceLoadFactorBending", value)

    @property
    @exception_bridge
    def face_load_factor_contact(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "FaceLoadFactorContact")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @face_load_factor_contact.setter
    @exception_bridge
    @enforce_parameter_types
    def face_load_factor_contact(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "FaceLoadFactorContact", value)

    @property
    @exception_bridge
    def friction_loss_multiplier(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "FrictionLossMultiplier")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @friction_loss_multiplier.setter
    @exception_bridge
    @enforce_parameter_types
    def friction_loss_multiplier(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "FrictionLossMultiplier", value)

    @property
    @exception_bridge
    def helical_gear_micro_geometry_option(
        self: "Self",
    ) -> "overridable.Overridable_HelicalGearMicroGeometryOption":
        """Overridable[mastapy.gears.rating.cylindrical.iso6336.HelicalGearMicroGeometryOption]"""
        temp = pythonnet_property_get(self.wrapped, "HelicalGearMicroGeometryOption")

        if temp is None:
            return None

        value = overridable.Overridable_HelicalGearMicroGeometryOption.wrapped_type()
        return overridable_enum_runtime.create(temp, value)

    @helical_gear_micro_geometry_option.setter
    @exception_bridge
    @enforce_parameter_types
    def helical_gear_micro_geometry_option(
        self: "Self",
        value: "Union[_623.HelicalGearMicroGeometryOption, Tuple[_623.HelicalGearMicroGeometryOption, bool]]",
    ) -> None:
        wrapper_type = (
            overridable.Overridable_HelicalGearMicroGeometryOption.wrapper_type()
        )
        enclosed_type = (
            overridable.Overridable_HelicalGearMicroGeometryOption.implicit_type()
        )
        value, is_overridden = _unpack_overridable(value)
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](
            value if value is not None else None, is_overridden
        )
        pythonnet_property_set(self.wrapped, "HelicalGearMicroGeometryOption", value)

    @property
    @exception_bridge
    def iso14179_part_1_coefficient_of_friction_constants_and_exponents_database(
        self: "Self",
    ) -> "str":
        """str"""
        temp = pythonnet_property_get_with_method(
            self.wrapped,
            "ISO14179Part1CoefficientOfFrictionConstantsAndExponentsDatabase",
            "SelectedItemName",
        )

        if temp is None:
            return ""

        return temp

    @iso14179_part_1_coefficient_of_friction_constants_and_exponents_database.setter
    @exception_bridge
    @enforce_parameter_types
    def iso14179_part_1_coefficient_of_friction_constants_and_exponents_database(
        self: "Self", value: "str"
    ) -> None:
        pythonnet_property_set_with_method(
            self.wrapped,
            "ISO14179Part1CoefficientOfFrictionConstantsAndExponentsDatabase",
            "SetSelectedItem",
            str(value) if value is not None else "",
        )

    @property
    @exception_bridge
    def lubrication_method_for_no_load_losses(
        self: "Self",
    ) -> "overridable.Overridable_LubricationMethodForNoLoadLossesCalc":
        """Overridable[mastapy.gears.LubricationMethodForNoLoadLossesCalc]"""
        temp = pythonnet_property_get(self.wrapped, "LubricationMethodForNoLoadLosses")

        if temp is None:
            return None

        value = (
            overridable.Overridable_LubricationMethodForNoLoadLossesCalc.wrapped_type()
        )
        return overridable_enum_runtime.create(temp, value)

    @lubrication_method_for_no_load_losses.setter
    @exception_bridge
    @enforce_parameter_types
    def lubrication_method_for_no_load_losses(
        self: "Self",
        value: "Union[_443.LubricationMethodForNoLoadLossesCalc, Tuple[_443.LubricationMethodForNoLoadLossesCalc, bool]]",
    ) -> None:
        wrapper_type = (
            overridable.Overridable_LubricationMethodForNoLoadLossesCalc.wrapper_type()
        )
        enclosed_type = (
            overridable.Overridable_LubricationMethodForNoLoadLossesCalc.implicit_type()
        )
        value, is_overridden = _unpack_overridable(value)
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](
            value if value is not None else None, is_overridden
        )
        pythonnet_property_set(self.wrapped, "LubricationMethodForNoLoadLosses", value)

    @property
    @exception_bridge
    def maximum_number_of_times_out_of_contact_before_being_considered_converged(
        self: "Self",
    ) -> "overridable.Overridable_int":
        """Overridable[int]"""
        temp = pythonnet_property_get(
            self.wrapped,
            "MaximumNumberOfTimesOutOfContactBeforeBeingConsideredConverged",
        )

        if temp is None:
            return 0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_int"
        )(temp)

    @maximum_number_of_times_out_of_contact_before_being_considered_converged.setter
    @exception_bridge
    @enforce_parameter_types
    def maximum_number_of_times_out_of_contact_before_being_considered_converged(
        self: "Self", value: "Union[int, Tuple[int, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0, is_overridden
        )
        pythonnet_property_set(
            self.wrapped,
            "MaximumNumberOfTimesOutOfContactBeforeBeingConsideredConverged",
            value,
        )

    @property
    @exception_bridge
    def micro_geometry_model_for_simple_mesh_stiffness(
        self: "Self",
    ) -> "_446.MicroGeometryModel":
        """mastapy.gears.MicroGeometryModel

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "MicroGeometryModelForSimpleMeshStiffness"
        )

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(temp, "SMT.MastaAPI.Gears.MicroGeometryModel")

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.gears._446", "MicroGeometryModel"
        )(value)

    @property
    @exception_bridge
    def misalignment(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "Misalignment")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @misalignment.setter
    @exception_bridge
    @enforce_parameter_types
    def misalignment(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "Misalignment", value)

    @property
    @exception_bridge
    def misalignment_due_to_manufacturing_tolerances(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(
            self.wrapped, "MisalignmentDueToManufacturingTolerances"
        )

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @misalignment_due_to_manufacturing_tolerances.setter
    @exception_bridge
    @enforce_parameter_types
    def misalignment_due_to_manufacturing_tolerances(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(
            self.wrapped, "MisalignmentDueToManufacturingTolerances", value
        )

    @property
    @exception_bridge
    def oil_flow_rate_constant(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "OilFlowRateConstant")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @oil_flow_rate_constant.setter
    @exception_bridge
    @enforce_parameter_types
    def oil_flow_rate_constant(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "OilFlowRateConstant", value)

    @property
    @exception_bridge
    def oil_flow_rate_specification_method(
        self: "Self",
    ) -> "overridable.Overridable_OilJetFlowRateSpecificationMethod":
        """Overridable[mastapy.gears.OilJetFlowRateSpecificationMethod]"""
        temp = pythonnet_property_get(self.wrapped, "OilFlowRateSpecificationMethod")

        if temp is None:
            return None

        value = overridable.Overridable_OilJetFlowRateSpecificationMethod.wrapped_type()
        return overridable_enum_runtime.create(temp, value)

    @oil_flow_rate_specification_method.setter
    @exception_bridge
    @enforce_parameter_types
    def oil_flow_rate_specification_method(
        self: "Self",
        value: "Union[_450.OilJetFlowRateSpecificationMethod, Tuple[_450.OilJetFlowRateSpecificationMethod, bool]]",
    ) -> None:
        wrapper_type = (
            overridable.Overridable_OilJetFlowRateSpecificationMethod.wrapper_type()
        )
        enclosed_type = (
            overridable.Overridable_OilJetFlowRateSpecificationMethod.implicit_type()
        )
        value, is_overridden = _unpack_overridable(value)
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](
            value if value is not None else None, is_overridden
        )
        pythonnet_property_set(self.wrapped, "OilFlowRateSpecificationMethod", value)

    @property
    @exception_bridge
    def oil_injection_direction(
        self: "Self",
    ) -> "overridable.Overridable_GearMeshOilInjectionDirection":
        """Overridable[mastapy.gears.GearMeshOilInjectionDirection]"""
        temp = pythonnet_property_get(self.wrapped, "OilInjectionDirection")

        if temp is None:
            return None

        value = overridable.Overridable_GearMeshOilInjectionDirection.wrapped_type()
        return overridable_enum_runtime.create(temp, value)

    @oil_injection_direction.setter
    @exception_bridge
    @enforce_parameter_types
    def oil_injection_direction(
        self: "Self",
        value: "Union[_449.GearMeshOilInjectionDirection, Tuple[_449.GearMeshOilInjectionDirection, bool]]",
    ) -> None:
        wrapper_type = (
            overridable.Overridable_GearMeshOilInjectionDirection.wrapper_type()
        )
        enclosed_type = (
            overridable.Overridable_GearMeshOilInjectionDirection.implicit_type()
        )
        value, is_overridden = _unpack_overridable(value)
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](
            value if value is not None else None, is_overridden
        )
        pythonnet_property_set(self.wrapped, "OilInjectionDirection", value)

    @property
    @exception_bridge
    def oil_jet_velocity_constant(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "OilJetVelocityConstant")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @oil_jet_velocity_constant.setter
    @exception_bridge
    @enforce_parameter_types
    def oil_jet_velocity_constant(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "OilJetVelocityConstant", value)

    @property
    @exception_bridge
    def oil_jet_velocity_specification_method(
        self: "Self",
    ) -> "overridable.Overridable_OilJetVelocitySpecificationMethod":
        """Overridable[mastapy.gears.OilJetVelocitySpecificationMethod]"""
        temp = pythonnet_property_get(self.wrapped, "OilJetVelocitySpecificationMethod")

        if temp is None:
            return None

        value = overridable.Overridable_OilJetVelocitySpecificationMethod.wrapped_type()
        return overridable_enum_runtime.create(temp, value)

    @oil_jet_velocity_specification_method.setter
    @exception_bridge
    @enforce_parameter_types
    def oil_jet_velocity_specification_method(
        self: "Self",
        value: "Union[_451.OilJetVelocitySpecificationMethod, Tuple[_451.OilJetVelocitySpecificationMethod, bool]]",
    ) -> None:
        wrapper_type = (
            overridable.Overridable_OilJetVelocitySpecificationMethod.wrapper_type()
        )
        enclosed_type = (
            overridable.Overridable_OilJetVelocitySpecificationMethod.implicit_type()
        )
        value, is_overridden = _unpack_overridable(value)
        value = conversion.mp_to_pn_enum(value, enclosed_type)
        value = wrapper_type[enclosed_type](
            value if value is not None else None, is_overridden
        )
        pythonnet_property_set(self.wrapped, "OilJetVelocitySpecificationMethod", value)

    @property
    @exception_bridge
    def override_misalignment_in_system_deflection_and_ltca(self: "Self") -> "bool":
        """bool"""
        temp = pythonnet_property_get(
            self.wrapped, "OverrideMisalignmentInSystemDeflectionAndLTCA"
        )

        if temp is None:
            return False

        return temp

    @override_misalignment_in_system_deflection_and_ltca.setter
    @exception_bridge
    @enforce_parameter_types
    def override_misalignment_in_system_deflection_and_ltca(
        self: "Self", value: "bool"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "OverrideMisalignmentInSystemDeflectionAndLTCA",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def permissible_specific_lubricant_film_thickness(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(
            self.wrapped, "PermissibleSpecificLubricantFilmThickness"
        )

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @permissible_specific_lubricant_film_thickness.setter
    @exception_bridge
    @enforce_parameter_types
    def permissible_specific_lubricant_film_thickness(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(
            self.wrapped, "PermissibleSpecificLubricantFilmThickness", value
        )

    @property
    @exception_bridge
    def transverse_load_factor_bending(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "TransverseLoadFactorBending")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @transverse_load_factor_bending.setter
    @exception_bridge
    @enforce_parameter_types
    def transverse_load_factor_bending(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "TransverseLoadFactorBending", value)

    @property
    @exception_bridge
    def transverse_load_factor_contact(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "TransverseLoadFactorContact")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @transverse_load_factor_contact.setter
    @exception_bridge
    @enforce_parameter_types
    def transverse_load_factor_contact(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "TransverseLoadFactorContact", value)

    @property
    @exception_bridge
    def use_design_iso14179_part_1_coefficient_of_friction_constants_and_exponents(
        self: "Self",
    ) -> "bool":
        """bool"""
        temp = pythonnet_property_get(
            self.wrapped,
            "UseDesignISO14179Part1CoefficientOfFrictionConstantsAndExponents",
        )

        if temp is None:
            return False

        return temp

    @use_design_iso14179_part_1_coefficient_of_friction_constants_and_exponents.setter
    @exception_bridge
    @enforce_parameter_types
    def use_design_iso14179_part_1_coefficient_of_friction_constants_and_exponents(
        self: "Self", value: "bool"
    ) -> None:
        pythonnet_property_set(
            self.wrapped,
            "UseDesignISO14179Part1CoefficientOfFrictionConstantsAndExponents",
            bool(value) if value is not None else False,
        )

    @property
    @exception_bridge
    def user_specified_coefficient_of_friction(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(
            self.wrapped, "UserSpecifiedCoefficientOfFriction"
        )

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @user_specified_coefficient_of_friction.setter
    @exception_bridge
    @enforce_parameter_types
    def user_specified_coefficient_of_friction(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(
            self.wrapped, "UserSpecifiedCoefficientOfFriction", value
        )

    @property
    @exception_bridge
    def user_specified_tooth_loss_factor(
        self: "Self",
    ) -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = pythonnet_property_get(self.wrapped, "UserSpecifiedToothLossFactor")

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @user_specified_tooth_loss_factor.setter
    @exception_bridge
    @enforce_parameter_types
    def user_specified_tooth_loss_factor(
        self: "Self", value: "Union[float, Tuple[float, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        pythonnet_property_set(self.wrapped, "UserSpecifiedToothLossFactor", value)

    @property
    @exception_bridge
    def volumetric_oil_air_mixture_ratio(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "VolumetricOilAirMixtureRatio")

        if temp is None:
            return 0.0

        return temp

    @property
    @exception_bridge
    def connection_design(self: "Self") -> "_2569.CylindricalGearMesh":
        """mastapy.system_model.connections_and_sockets.gears.CylindricalGearMesh

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "ConnectionDesign")

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def iso14179_coefficient_of_friction_constants_and_exponents(
        self: "Self",
    ) -> "_721.ISOTR1417912001CoefficientOfFrictionConstants":
        """mastapy.gears.materials.ISOTR1417912001CoefficientOfFrictionConstants

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(
            self.wrapped, "ISO14179CoefficientOfFrictionConstantsAndExponents"
        )

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    @exception_bridge
    def planetaries(self: "Self") -> "List[CylindricalGearMeshLoadCase]":
        """List[mastapy.system_model.analyses_and_results.static_loads.CylindricalGearMeshLoadCase]

        Note:
            This property is readonly.
        """
        temp = pythonnet_property_get(self.wrapped, "Planetaries")

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @exception_bridge
    def get_harmonic_load_data_for_import(
        self: "Self",
    ) -> "_7787.CylindricalGearSetHarmonicLoadData":
        """mastapy.system_model.analyses_and_results.static_loads.CylindricalGearSetHarmonicLoadData"""
        method_result = pythonnet_method_call(
            self.wrapped, "GetHarmonicLoadDataForImport"
        )
        if method_result is None:
            return None

        type_ = method_result.GetType()
        return constructor.new(type_.Namespace, type_.Name)(method_result)

    @property
    def cast_to(self: "Self") -> "_Cast_CylindricalGearMeshLoadCase":
        """Cast to another type.

        Returns:
            _Cast_CylindricalGearMeshLoadCase
        """
        return _Cast_CylindricalGearMeshLoadCase(self)



"""VDI2736LubricantType"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal.python_net import python_net_import

_VDI2736_LUBRICANT_TYPE = python_net_import(
    "SMT.MastaAPI.Materials", "VDI2736LubricantType"
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    Self = TypeVar("Self", bound="VDI2736LubricantType")
    CastSelf = TypeVar(
        "CastSelf", bound="VDI2736LubricantType._Cast_VDI2736LubricantType"
    )


__docformat__ = "restructuredtext en"
__all__ = ("VDI2736LubricantType",)


class VDI2736LubricantType(Enum):
    """VDI2736LubricantType

    This is a mastapy class.

    Note:
        This class is an Enum.
    """

    @classmethod
    def type_(cls) -> "Type":
        return _VDI2736_LUBRICANT_TYPE

    OIL = 0
    GREASE = 1
    WATEROIL_EMULSION = 2
    OIL_MIST = 3
    NONE_DRY_RUNNING = 4


def __enum_setattr(self: "Self", attr: str, value: "Any") -> None:
    raise AttributeError("Cannot set the attributes of an Enum.") from None


def __enum_delattr(self: "Self", attr: str) -> None:
    raise AttributeError("Cannot delete the attributes of an Enum.") from None


VDI2736LubricantType.__setattr__ = __enum_setattr
VDI2736LubricantType.__delattr__ = __enum_delattr



"""Subpackage."""

from typing import TYPE_CHECKING as __tc

if __tc:
    from mastapy._private.gears.rating.straight_bevel_diff._511 import (
        StraightBevelDiffGearMeshRating,
    )
    from mastapy._private.gears.rating.straight_bevel_diff._512 import (
        StraightBevelDiffGearRating,
    )
    from mastapy._private.gears.rating.straight_bevel_diff._513 import (
        StraightBevelDiffGearSetRating,
    )
    from mastapy._private.gears.rating.straight_bevel_diff._514 import (
        StraightBevelDiffMeshedGearRating,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.gears.rating.straight_bevel_diff._511": [
            "StraightBevelDiffGearMeshRating"
        ],
        "_private.gears.rating.straight_bevel_diff._512": [
            "StraightBevelDiffGearRating"
        ],
        "_private.gears.rating.straight_bevel_diff._513": [
            "StraightBevelDiffGearSetRating"
        ],
        "_private.gears.rating.straight_bevel_diff._514": [
            "StraightBevelDiffMeshedGearRating"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "StraightBevelDiffGearMeshRating",
    "StraightBevelDiffGearRating",
    "StraightBevelDiffGearSetRating",
    "StraightBevelDiffMeshedGearRating",
)
